[pacman-dev] [PATCH 1/3] Use execvp for running programs in chroot

Allan McRae allan at archlinux.org
Sun Jul 15 21:41:27 EDT 2012


This makes us more robust to utilities changing paths.  There is no
functional change when a full path is specified.

Signed-off-by: Allan McRae <allan at archlinux.org>
---
 lib/libalpm/util.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/lib/libalpm/util.c b/lib/libalpm/util.c
index c2b5d44..bdb9e56 100644
--- a/lib/libalpm/util.c
+++ b/lib/libalpm/util.c
@@ -549,9 +549,9 @@ int _alpm_run_chroot(alpm_handle_t *handle, const char *cmd, char *const argv[])
 			exit(1);
 		}
 		umask(0022);
-		execv(cmd, argv);
-		/* execv only returns if there was an error */
-		fprintf(stderr, _("call to execv failed (%s)\n"), strerror(errno));
+		execvp(cmd, argv);
+		/* execvp only returns if there was an error */
+		fprintf(stderr, _("call to execvp failed (%s)\n"), strerror(errno));
 		exit(1);
 	} else {
 		/* this code runs for the parent only (wait on the child) */
-- 
1.7.11.2



More information about the pacman-dev mailing list